==> seedsui-react-5.5.91.tgz: package/lib/Input/Text/index.js <==
var _excluded = ["type", "autoFit", "readOnly", "disabled", "inputProps", "defaultValue", "value", "precision", "max", "min", "placeholder", "maxLength", "autoFocus", "autoSelect", "licon", "liconProps", "ricon", "riconProps", "allowClear", "clearProps", "rcaption", "children", "onClick", "onCompositionStart", "onCompositionUpdate", "onCompositionEnd", "onInput", "onChange", "onBlur", "onFocus"],
    _excluded2 = ["visible"];

function ownKeys(object, enumerableOnly) { var keys = Object.keys(object); if (Object.getOwnPropertySymbols) { var symbols = Object.getOwnPropertySymbols(object); enumerableOnly && (symbols = symbols.filter(function (sym) { return Object.getOwnPropertyDescriptor(object, sym).enumerable; })), keys.push.apply(keys, symbols); } return keys; }

function _objectSpread(target) { for (var i = 1; i < arguments.length; i++) { var source = null != arguments[i] ? arguments[i] : {}; i % 2 ? ownKeys(Object(source), !0).forEach(function (key) { _defineProperty(target, key, source[key]); }) : Object.getOwnPropertyDescriptors ? Object.defineProperties(target, Object.getOwnPropertyDescriptors(source)) : ownKeys(Object(source)).forEach(function (key) { Object.defineProperty(target, key, Object.getOwnPropertyDescriptor(source, key)); }); } return target; }

function _defineProperty(obj, key, value) { if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }

function _slicedToArray(arr, i) { return _arrayWithHoles(arr) || _iterableToArrayLimit(arr, i) || _unsupportedIterableToArray(arr, i) || _nonIterableRest(); }

function _nonIterableRest() { throw new TypeError("Invalid attempt to destructure non-iterable instance.\nIn order to be iterable, non-array objects must have a [Symbol.iterator]() method."); }

function _unsupportedIterableToArray(o, minLen) { if (!o) return; if (typeof o === "string") return _arrayLikeToArray(o, minLen); var n = Object.prototype.toString.call(o).slice(8, -1); if (n === "Object" && o.constructor) n = o.constructor.name; if (n === "Map" || n === "Set") return Array.from(o); if (n === "Arguments" || /^(?:Ui|I)nt(?:8|16|32)(?:Clamped)?Array$/.test(n)) return _arrayLikeToArray(o, minLen); }

function _arrayLikeToArray(arr, len) { if (len == null || len > arr.length) len = arr.length; for (var i = 0, arr2 = new Array(len); i < len; i++) { arr2[i] = arr[i]; } return arr2; }

function _iterableToArrayLimit(arr, i) { var _i = arr == null ? null : typeof Symbol !== "undefined" && arr[Symbol.iterator] || arr["@@iterator"]; if (_i == null) return; var _arr = []; var _n = true; var _d = false; var _s, _e; try { for (_i = _i.call(arr); !(_n = (_s = _i.next()).done); _n = true) { _arr.push(_s.value); if (i && _arr.length === i) break; } } catch (err) { _d = true; _e = err; } finally { try { if (!_n && _i["return"] != null) _i["return"](); } finally { if (_d) throw _e; } } return _arr; }

function _arrayWithHoles(arr) { if (Array.isArray(arr)) return arr; }

function _objectWithoutProperties(source, excluded) { if (source == null) return {}; var target = _objectWithoutPropertiesLoose(source, excluded); var key, i; if (Object.getOwnPropertySymbols) { var sourceSymbolKeys = Object.getOwnPropertySymbols(source); for (i = 0; i < sourceSymbolKeys.length; i++) { key = sourceSymbolKeys[i]; if (excluded.indexOf(key) >= 0) continue; if (!Object.prototype.propertyIsEnumerable.call(source, key)) continue; target[key] = source[key]; } } return target; }

function _objectWithoutPropertiesLoose(source, excluded) { if (source == null) return {}; var target = {}; var sourceKeys = Object.keys(source); var key, i; for (i = 0; i < sourceKeys.length; i++) { key = sourceKeys[i]; if (excluded.indexOf(key) >= 0) continue; target[key] = source[key]; } return target; }

import React, { forwardRef, useRef, useImperativeHandle, useEffect, useState } from 'react';
import { jsx as _jsx } from "react/jsx-runtime";
import { jsxs as _jsxs } from "react/jsx-runtime";
var InputText = /*#__PURE__*/forwardRef(function (_ref, ref) {
  var _ref$type = _ref.type,
      type = _ref$type === void 0 ? 'text' : _ref$type,
      autoFit = _ref.autoFit,
      readOnly = _ref.readOnly,
      disabled = _ref.disabled,
      _ref$inputProps = _ref.inputProps,
      inputProps = _ref$inputProps === void 0 ? {} : _ref$inputProps,
      defaultValue = _ref.defaultValue,
      value = _ref.value,
      precision = _ref.precision,
      max = _ref.max,
      min = _ref.min,
      placeholder = _ref.placeholder,
      maxLength = _ref.maxLength,
      autoFocus = _ref.autoFocus,
      autoSelect = _ref.autoSelect,
      licon = _ref.licon,
      liconProps = _ref.liconProps,
      ricon = _ref.ricon,
      riconProps = _ref.riconProps,
      allowClear = _ref.allowClear,
      clearProps = _ref.clearProps,
      rcaption = _ref.rcaption,
      children = _ref.children,
      onClick = _ref.onClick,
      onCompositionStart = _ref.onCompositionStart,
      onCompositionUpdate = _ref.onCompositionUpdate,
      onCompositionEnd = _ref.onCompositionEnd,
      onInput = _ref.onInput,
      onChange = _ref.onChange,
      onBlur = _ref.onBlur,
      onFocus = _ref.onFocus,
      props = _objectWithoutProperties(_ref, _excluded);

  // 清空按钮显示
  var _useState = useState(false),
      _useState2 = _slicedToArray(_useState, 2),
      clearVisible = _useState2[0],
      setClearVisible = _useState2[1]; // 节点


  var rootRef = useRef(null);
  var inputRef = useRef(null);
  var fitRef = useRef(null);
  useImperativeHandle(ref, function () {
    return {
      rootDOM: rootRef.current,
      inputDOM: inputRef.current,
      getRootDOM: function getRootDOM() {
        return rootRef.current;
      },
      getInputDOM: function getInputDOM() {
        return inputRef.current;
      },
      correctText: correctText,
      focus: _focus
    };
  });
  useEffect(function () {
    var val = inputRef.current.value; // 更新清除按钮和自适应的高度

    updateClear(val);
    updateAutoFit(val); // 自动获取焦点

    if (autoFocus) {
      _focus();
    }
  }, []); // eslint-disable-line

  useEffect(function () {
    updateContainer();
  }, [value]); // eslint-disable-line
  // 更新文本框高度和清空按钮

  function updateContainer() {
    if (!(rootRef !== null && rootRef !== void 0 && rootRef.current)) return;

    if (rootRef.current.inputTimeout) {
      clearTimeout(rootRef.current.inputTimeout);
    }

    rootRef.current.inputTimeout = setTimeout(function () {
      if (!(inputRef !== null && inputRef !== void 0 && inputRef.current)) return;
      var val = inputRef.current.value; // 更新清除按钮和自适应的高度

      updateClear(val);
      updateAutoFit(val);
    }, 100);
  } // 更新清除按钮


  function updateClear(val) {
    if (typeof val === 'number') {
      val = String(val);
    } // 只读是否允许清空


    var allowClearReadOnly = false;

    if (allowClear === 'readOnly') {
      allowClearReadOnly = true;
    } // 只读不允许清空


    if (!allowClearReadOnly && (readOnly || disabled)) {
      return;
    }

    if (val) {
      setClearVisible(true);
    } else {
      setClearVisible(false);
    }
  } // 自动扩充功能


  function updateAutoFit(val) {
    if (!autoFit) return;
    fitRef.current.children[0].innerText = val; // 多行文本框使用样式宽高100%, 放弃使用js控制高度
    // inputRef.current.style.height = fitRef.current.clientHeight + 'px'
  } // 矫正最大长度和小数位截取


  function correctText(val) {
    if (val === '') return val;
    if (typeof val === 'number') val = String(val); // 最大长度

    if (maxLength && val && val.length > maxLength) {
      val = val.substring(0, maxLength);
    } // 小数位截取


    if (typeof precision === 'number') {
      if (val.indexOf('.') !== -1) {
        val = val.substring(0, val.indexOf('.') + Number(precision) + 1);
      }
    } // 数值框


    if (type === 'number' && val) {
      val = Number(val);
    }

    return val;
  } // 获取焦点


  function _focus() {
    if (disabled || readOnly || !inputRef.current) return;
    inputRef.current.focus(); // 只有获取焦点以后才能选中

    if (autoSelect) {
      inputRef.current.select();
    }
  } // 获取焦点时, 如果readOnly或者disabled时, 需要立即失去焦点, 解决ios会出现底栏的问题


  function handleFocus(e) {
    if (readOnly || disabled) {
      e.target.blur();
      return;
    }

    if (onFocus) onFocus(e);
  } // 清空按钮控制


  function handleInput(e) {
    // 非受控组件需要操作DOM
    if (defaultValue || defaultValue === '') {
      updateContainer();
    } // Callback


    if (onInput) onInput(e);
  } // 修改值


  function handleChange(e) {
    var _target$validity;

    var target = e.target;
    var val = target.value; // 输入值不合法

    if (target !== null && target !== void 0 && (_target$validity = target.validity) !== null && _target$validity !== void 0 && _target$validity.badInput) {
      val = '';
    } // 矫正maxLength和小数点位数


    val = correctText(val); // 非受控组件需要操作DOM

    if (defaultValue || defaultValue === '') {
      target.value = val;
    }

    if (onChange) {
      onChange(val);
    }
  } // 数值框失去焦点, 校验最大值和最小值


  function handleBlur(e) {
    if (readOnly || disabled) {
      return;
    }

    var target = e.target;
    var val = target.value;

    if (val && !isNaN(val)) {
      // 输入时只校验最大值、小数点、最大长度、返回错误
      if (typeof max === 'number') {
        if (Number(val) > Number(max)) val = max;
      }

      if (typeof min === 'number') {
        if (Number(val) < Number(min)) val = min;
      } // 纠正数字


      val = correctText(val); // 修改完回调

      if (val !== value) {
        if (onChange) onChange(val);
      }
    }

    if (onBlur) onBlur(e);
  } // 点击清除


  function handleClear(e) {
    e.stopPropagation(); // 获取焦点

    _focus(); // Callback


    if (onChange) {
      onChange('');
    } // 非受控组件需要操作DOM


    if (defaultValue || defaultValue === '') {
      updateContainer();
    }
  } // render


  function getInputDOM() {
    // 剔除掉onClick事件, 因为在容器onClick已经回调了
    var inputVisible = inputProps.visible,
        otherInputProps = _objectWithoutProperties(inputProps, _excluded2);

    if (inputVisible === false) return null; // autoFit类型

    if (autoFit) {
      // pre的左右padding
      var fitLeft = 0;
      var fitRight = 0;

      if (otherInputProps.style) {
        if (otherInputProps.style.padding) {
          var paddingValues = otherInputProps.style.padding.split(' ');

          if (paddingValues.length === 1) {
            fitLeft = paddingValues[0];
            fitRight = paddingValues[0];
          } else if (paddingValues.length === 2) {
            fitLeft = paddingValues[1];
            fitRight = paddingValues[1];
          } else if (paddingValues.length === 4) {
            fitLeft = paddingValues[1];
            fitRight = paddingValues[3];
          }
        } else if (otherInputProps.style.paddingLeft || otherInputProps.style.paddingRight) {
          fitLeft = otherInputProps.style.paddingLeft || '0';
          fitRight = otherInputProps.style.paddingRight || '0';
        }
      }

      return /*#__PURE__*/_jsxs("div", _objectSpread(_objectSpread({}, otherInputProps), {}, {
        className: "input-fit-wrapper".concat(otherInputProps.className ? ' ' + otherInputProps.className : ''),
        children: [/*#__PURE__*/_jsx("div", {
          className: "input-fit",
          children: /*#__PURE__*/_jsx("textarea", {
            ref: inputRef,
            autoFocus: autoFocus,
            value: value,
            defaultValue: defaultValue,
            maxLength: maxLength,
            readOnly: readOnly,
            disabled: disabled,
            placeholder: placeholder,
            onChange: handleChange,
            onInput: handleInput,
            onBlur: handleBlur,
            onFocus: handleFocus
          })
        }), /*#__PURE__*/_jsx("pre", {
          ref: fitRef,
          style: {
            left: fitLeft,
            right: fitRight
          },
          children: /*#__PURE__*/_jsx("span", {})
        })]
      }));
    } // textarea类型


    if (type === 'textarea') {
      // 如果值绑定属性,则只有通过父组件的prop来改变值
      return /*#__PURE__*/_jsx("textarea", _objectSpread(_objectSpread({
        ref: inputRef
      }, otherInputProps), {}, {
        autoFocus: autoFocus,
        value: value,
        defaultValue: defaultValue,
        maxLength: maxLength,
        readOnly: readOnly,
        disabled: disabled,
        placeholder: placeholder,
        onChange: handleChange,
        onInput: handleInput,
        onBlur: handleBlur,
        onFocus: handleFocus,
        className: "input-textarea".concat(otherInputProps.className ? ' ' + otherInputProps.className : '')
      }));
    } // 其它类型


    return /*#__PURE__*/_jsx("input", _objectSpread(_objectSpread({
      ref: inputRef,
      type: type
    }, otherInputProps), {}, {
      className: "input-text".concat(otherInputProps.className ? ' ' + otherInputProps.className : ''),
      defaultValue: defaultValue,
      value: value,
      min: typeof min === 'number' ? min : '',
      max: typeof max === 'number' ? max : '',
      maxLength: maxLength,
      disabled: disabled,
      readOnly: readOnly,
      placeholder: placeholder,
      onChange: handleChange,
      onInput: handleInput,
      autoFocus: autoFocus,
      onBlur: handleBlur,
      onFocus: handleFocus
    }));
  }

  return /*#__PURE__*/_jsxs("div", _objectSpread(_objectSpread({
    ref: rootRef
  }, props), {}, {
    className: "input-wrapper".concat(props.className ? ' ' + props.className : ''),
    onClick: onClick,
    children: [licon && licon, liconProps && /*#__PURE__*/_jsx("i", _objectSpread(_objectSpread({}, liconProps), {}, {
      className: "licon icon".concat(liconProps !== null && liconProps !== void 0 && liconProps.className ? ' ' + (liconProps === null || liconProps === void 0 ? void 0 : liconProps.className) : '')
    })), getInputDOM(), children && children, clearVisible && allowClear && /*#__PURE__*/_jsx("i", _objectSpread(_objectSpread({}, clearProps), {}, {
      className: "icon clearicon".concat(clearProps !== null && clearProps !== void 0 && clearProps.className ? ' ' + (clearProps === null || clearProps === void 0 ? void 0 : clearProps.className) : ' ricon close-icon-clear size18'),
      onClick: handleClear
    })), riconProps && /*#__PURE__*/_jsx("i", _objectSpread(_objectSpread({}, riconProps), {}, {
      className: "ricon icon".concat(riconProps !== null && riconProps !== void 0 && riconProps.className ? ' ' + (riconProps === null || riconProps === void 0 ? void 0 : riconProps.className) : '')
    })), ricon && ricon, rcaption && rcaption]
  }));
});
export default InputText;

==> seedsui-react-5.5.92.tgz: package/lib/Input/Text/index.js <==
var _excluded = ["type", "autoFit", "readOnly", "disabled", "inputProps", "defaultValue", "value", "precision", "max", "min", "placeholder", "maxLength", "autoFocus", "autoSelect", "licon", "liconProps", "ricon", "riconProps", "allowClear", "clearProps", "rcaption", "children", "onClick", "onCompositionStart", "onCompositionUpdate", "onCompositionEnd", "onInput", "onChange", "onBlur", "onFocus"],
    _excluded2 = ["visible"];

function _extends() { _extends = Object.assign ? Object.assign.bind() : function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; }; return _extends.apply(this, arguments); }

function _slicedToArray(arr, i) { return _arrayWithHoles(arr) || _iterableToArrayLimit(arr, i) || _unsupportedIterableToArray(arr, i) || _nonIterableRest(); }

function _nonIterableRest() { throw new TypeError("Invalid attempt to destructure non-iterable instance.\nIn order to be iterable, non-array objects must have a [Symbol.iterator]() method."); }

function _unsupportedIterableToArray(o, minLen) { if (!o) return; if (typeof o === "string") return _arrayLikeToArray(o, minLen); var n = Object.prototype.toString.call(o).slice(8, -1); if (n === "Object" && o.constructor) n = o.constructor.name; if (n === "Map" || n === "Set") return Array.from(o); if (n === "Arguments" || /^(?:Ui|I)nt(?:8|16|32)(?:Clamped)?Array$/.test(n)) return _arrayLikeToArray(o, minLen); }

function _arrayLikeToArray(arr, len) { if (len == null || len > arr.length) len = arr.length; for (var i = 0, arr2 = new Array(len); i < len; i++) { arr2[i] = arr[i]; } return arr2; }

function _iterableToArrayLimit(arr, i) { var _i = arr == null ? null : typeof Symbol !== "undefined" && arr[Symbol.iterator] || arr["@@iterator"]; if (_i == null) return; var _arr = []; var _n = true; var _d = false; var _s, _e; try { for (_i = _i.call(arr); !(_n = (_s = _i.next()).done); _n = true) { _arr.push(_s.value); if (i && _arr.length === i) break; } } catch (err) { _d = true; _e = err; } finally { try { if (!_n && _i["return"] != null) _i["return"](); } finally { if (_d) throw _e; } } return _arr; }

function _arrayWithHoles(arr) { if (Array.isArray(arr)) return arr; }

function _objectWithoutProperties(source, excluded) { if (source == null) return {}; var target = _objectWithoutPropertiesLoose(source, excluded); var key, i; if (Object.getOwnPropertySymbols) { var sourceSymbolKeys = Object.getOwnPropertySymbols(source); for (i = 0; i < sourceSymbolKeys.length; i++) { key = sourceSymbolKeys[i]; if (excluded.indexOf(key) >= 0) continue; if (!Object.prototype.propertyIsEnumerable.call(source, key)) continue; target[key] = source[key]; } } return target; }

function _objectWithoutPropertiesLoose(source, excluded) { if (source == null) return {}; var target = {}; var sourceKeys = Object.keys(source); var key, i; for (i = 0; i < sourceKeys.length; i++) { key = sourceKeys[i]; if (excluded.indexOf(key) >= 0) continue; target[key] = source[key]; } return target; }

import React, { forwardRef, useRef, useImperativeHandle, useEffect, useState } from 'react';
var InputText = /*#__PURE__*/forwardRef(function (_ref, ref) {
  var _ref$type = _ref.type,
      type = _ref$type === void 0 ? 'text' : _ref$type,
      autoFit = _ref.autoFit,
      readOnly = _ref.readOnly,
      disabled = _ref.disabled,
      _ref$inputProps = _ref.inputProps,
      inputProps = _ref$inputProps === void 0 ? {} : _ref$inputProps,
      defaultValue = _ref.defaultValue,
      value = _ref.value,
      precision = _ref.precision,
      max = _ref.max,
      min = _ref.min,
      placeholder = _ref.placeholder,
      maxLength = _ref.maxLength,
      autoFocus = _ref.autoFocus,
      autoSelect = _ref.autoSelect,
      licon = _ref.licon,
      liconProps = _ref.liconProps,
      ricon = _ref.ricon,
      riconProps = _ref.riconProps,
      allowClear = _ref.allowClear,
      clearProps = _ref.clearProps,
      rcaption = _ref.rcaption,
      children = _ref.children,
      onClick = _ref.onClick,
      onCompositionStart = _ref.onCompositionStart,
      onCompositionUpdate = _ref.onCompositionUpdate,
      onCompositionEnd = _ref.onCompositionEnd,
      onInput = _ref.onInput,
      onChange = _ref.onChange,
      onBlur = _ref.onBlur,
      onFocus = _ref.onFocus,
      props = _objectWithoutProperties(_ref, _excluded);

  // 清空按钮显示
  var _useState = useState(false),
      _useState2 = _slicedToArray(_useState, 2),
      clearVisible = _useState2[0],
      setClearVisible = _useState2[1]; // 节点


  var rootRef = useRef(null);
  var inputRef = useRef(null);
  var fitRef = useRef(null);
  useImperativeHandle(ref, function () {
    return {
      rootDOM: rootRef.current,
      inputDOM: inputRef.current,
      getRootDOM: function getRootDOM() {
        return rootRef.current;
      },
      getInputDOM: function getInputDOM() {
        return inputRef.current;
      },
      correctText: correctText,
      focus: _focus
    };
  });
  useEffect(function () {
    var val = inputRef.current.value; // 更新清除按钮和自适应的高度

    updateClear(val);
    updateAutoFit(val); // 自动获取焦点

    if (autoFocus) {
      _focus();
    }
  }, []); // eslint-disable-line

  useEffect(function () {
    updateContainer();
  }, [value]); // eslint-disable-line
  // 更新文本框高度和清空按钮

  function updateContainer() {
    if (!(rootRef !== null && rootRef !== void 0 && rootRef.current)) return;

    if (rootRef.current.inputTimeout) {
      clearTimeout(rootRef.current.inputTimeout);
    }

    rootRef.current.inputTimeout = setTimeout(function () {
      if (!(inputRef !== null && inputRef !== void 0 && inputRef.current)) return;
      var val = inputRef.current.value; // 更新清除按钮和自适应的高度

      updateClear(val);
      updateAutoFit(val);
    }, 100);
  } // 更新清除按钮


  function updateClear(val) {
    if (typeof val === 'number') {
      val = String(val);
    } // 只读是否允许清空


    var allowClearReadOnly = false;

    if (allowClear === 'readOnly') {
      allowClearReadOnly = true;
    } // 只读不允许清空


    if (!allowClearReadOnly && (readOnly || disabled)) {
      return;
    }

    if (val) {
      setClearVisible(true);
    } else {
      setClearVisible(false);
    }
  } // 自动扩充功能


  function updateAutoFit(val) {
    if (!autoFit) return;
    fitRef.current.children[0].innerText = val; // 多行文本框使用样式宽高100%, 放弃使用js控制高度
    // inputRef.current.style.height = fitRef.current.clientHeight + 'px'
  } // 矫正最大长度和小数位截取


  function correctText(val) {
    if (val === '') return val;
    if (typeof val === 'number') val = String(val); // 最大长度

    if (maxLength && val && val.length > maxLength) {
      val = val.substring(0, maxLength);
    } // 小数位截取


    if (typeof precision === 'number') {
      if (val.indexOf('.') !== -1) {
        val = val.substring(0, val.indexOf('.') + Number(precision) + 1);
      }
    } // 数值框


    if (type === 'number' && val) {
      val = Number(val);
    }

    return val;
  } // 获取焦点


  function _focus() {
    if (disabled || readOnly || !inputRef.current) return;
    inputRef.current.focus(); // 只有获取焦点以后才能选中

    if (autoSelect) {
      inputRef.current.select();
    }
  } // 获取焦点时, 如果readOnly或者disabled时, 需要立即失去焦点, 解决ios会出现底栏的问题


  function handleFocus(e) {
    if (readOnly || disabled) {
      e.target.blur();
      return;
    }

    if (onFocus) onFocus(e);
  } // 清空按钮控制


  function handleInput(e) {
    // 非受控组件需要操作DOM
    if (defaultValue || defaultValue === '') {
      updateContainer();
    } // Callback


    if (onInput) onInput(e);
  } // 修改值


  function handleChange(e) {
    var _target$validity;

    var target = e.target;
    var val = target.value; // 输入值不合法

    if (target !== null && target !== void 0 && (_target$validity = target.validity) !== null && _target$validity !== void 0 && _target$validity.badInput) {
      val = '';
    } // 矫正maxLength和小数点位数


    val = correctText(val); // 非受控组件需要操作DOM

    if (defaultValue || defaultValue === '') {
      target.value = val;
    }

    if (onChange) {
      onChange(val);
    }
  } // 数值框失去焦点, 校验最大值和最小值


  function handleBlur(e) {
    if (readOnly || disabled) {
      return;
    }

    var target = e.target;
    var val = target.value;

    if (val && !isNaN(val)) {
      // 输入时只校验最大值、小数点、最大长度、返回错误
      if (typeof max === 'number') {
        if (Number(val) > Number(max)) val = max;
      }

      if (typeof min === 'number') {
        if (Number(val) < Number(min)) val = min;
      } // 纠正数字


      val = correctText(val); // 修改完回调

      if (val !== value) {
        if (onChange) onChange(val);
      }
    }

    if (onBlur) onBlur(e);
  } // 点击清除


  function handleClear(e) {
    e.stopPropagation(); // 获取焦点

    _focus(); // Callback


    if (onChange) {
      onChange('');
    } // 非受控组件需要操作DOM


    if (defaultValue || defaultValue === '') {
      updateContainer();
    }
  } // render


  function getInputDOM() {
    // 剔除掉onClick事件, 因为在容器onClick已经回调了
    var inputVisible = inputProps.visible,
        otherInputProps = _objectWithoutProperties(inputProps, _excluded2);

    if (inputVisible === false) return null; // autoFit类型

    if (autoFit) {
      // pre的左右padding
      var fitLeft = 0;
      var fitRight = 0;

      if (otherInputProps.style) {
        if (otherInputProps.style.padding) {
          var paddingValues = otherInputProps.style.padding.split(' ');

          if (paddingValues.length === 1) {
            fitLeft = paddingValues[0];
            fitRight = paddingValues[0];
          } else if (paddingValues.length === 2) {
            fitLeft = paddingValues[1];
            fitRight = paddingValues[1];
          } else if (paddingValues.length === 4) {
            fitLeft = paddingValues[1];
            fitRight = paddingValues[3];
          }
        } else if (otherInputProps.style.paddingLeft || otherInputProps.style.paddingRight) {
          fitLeft = otherInputProps.style.paddingLeft || '0';
          fitRight = otherInputProps.style.paddingRight || '0';
        }
      }

      return /*#__PURE__*/React.createElement("div", _extends({}, otherInputProps, {
        className: "input-fit-wrapper".concat(otherInputProps.className ? ' ' + otherInputProps.className : '')
      }), /*#__PURE__*/React.createElement("div", {
        className: "input-fit"
      }, /*#__PURE__*/React.createElement("textarea", {
        ref: inputRef,
        autoFocus: autoFocus,
        value: value,
        defaultValue: defaultValue,
        maxLength: maxLength,
        readOnly: readOnly,
        disabled: disabled,
        placeholder: placeholder,
        onChange: handleChange,
        onInput: handleInput,
        onBlur: handleBlur,
        onFocus: handleFocus
      })), /*#__PURE__*/React.createElement("pre", {
        ref: fitRef,
        style: {
          left: fitLeft,
          right: fitRight
        }
      }, /*#__PURE__*/React.createElement("span", null)));
    } // textarea类型


    if (type === 'textarea') {
      // 如果值绑定属性,则只有通过父组件的prop来改变值
      return /*#__PURE__*/React.createElement("textarea", _extends({
        ref: inputRef
      }, otherInputProps, {
        autoFocus: autoFocus,
        value: value,
        defaultValue: defaultValue,
        maxLength: maxLength,
        readOnly: readOnly,
        disabled: disabled,
        placeholder: placeholder,
        onChange: handleChange,
        onInput: handleInput,
        onBlur: handleBlur,
        onFocus: handleFocus,
        className: "input-textarea".concat(otherInputProps.className ? ' ' + otherInputProps.className : '')
      }));
    } // 其它类型


    return /*#__PURE__*/React.createElement("input", _extends({
      ref: inputRef,
      type: type
    }, otherInputProps, {
      className: "input-text".concat(otherInputProps.className ? ' ' + otherInputProps.className : ''),
      defaultValue: defaultValue,
      value: value,
      min: typeof min === 'number' ? min : '',
      max: typeof max === 'number' ? max : '',
      maxLength: maxLength,
      disabled: disabled,
      readOnly: readOnly,
      placeholder: placeholder,
      onChange: handleChange,
      onInput: handleInput,
      autoFocus: autoFocus,
      onBlur: handleBlur,
      onFocus: handleFocus
    }));
  }

  return /*#__PURE__*/React.createElement("div", _extends({
    ref: rootRef
  }, props, {
    className: "input-wrapper".concat(props.className ? ' ' + props.className : ''),
    onClick: onClick
  }), licon && licon, liconProps && /*#__PURE__*/React.createElement("i", _extends({}, liconProps, {
    className: "licon icon".concat(liconProps !== null && liconProps !== void 0 && liconProps.className ? ' ' + (liconProps === null || liconProps === void 0 ? void 0 : liconProps.className) : '')
  })), getInputDOM(), children && children, clearVisible && allowClear && /*#__PURE__*/React.createElement("i", _extends({}, clearProps, {
    className: "icon clearicon".concat(clearProps !== null && clearProps !== void 0 && clearProps.className ? ' ' + (clearProps === null || clearProps === void 0 ? void 0 : clearProps.className) : ' ricon close-icon-clear size18'),
    onClick: handleClear
  })), riconProps && /*#__PURE__*/React.createElement("i", _extends({}, riconProps, {
    className: "ricon icon".concat(riconProps !== null && riconProps !== void 0 && riconProps.className ? ' ' + (riconProps === null || riconProps === void 0 ? void 0 : riconProps.className) : '')
  })), ricon && ricon, rcaption && rcaption);
});
export default InputText;
